@@ -13,7 +13,9 @@ class ProxyTypeFactory:
 
 class ProxyType:
     """
-    Set of possible types of proxy. Proxy type has 2 property -
+    Set of possible types of proxy.
+
+    Each proxy type has 2 properties:
        'ff_value' is value of Firefox profile preference,
        'string' is id of proxy type.
     """
@@ -26,6 +28,15 @@ class ProxyType:
     SYSTEM = ProxyTypeFactory.make(5, 'SYSTEM')           # Use system settings (default on Linux).
     UNSPECIFIED = ProxyTypeFactory.make(6, 'UNSPECIFIED') # Not initialized (for internal use).
 
+    @classmethod
+    def load(cls, value):
+        value = str(value).upper()
+        for attr in dir(cls):
+            attr_value = getattr(cls, attr)
+            if isinstance(attr_value, dict) and attr_value.has_key('string') and \
+                attr_value['string'] is not None and attr_value['string'] == value:
+                return attr_value
+        raise Exception("No proxy type is found for %s" % (value))
 
 class Proxy(object):
     """
@@ -39,6 +50,9 @@ class Proxy(object):
     noProxy = ''
     proxyAutoconfigUrl = ''
     sslProxy = ''
+    socksProxy = ''
+    socksUsername = ''
+    socksPassword = ''
 
     def __init__(self, raw=None):
         """
@@ -49,7 +63,7 @@ class Proxy(object):
         """
         if raw is not None:
             if 'proxyType' in raw and raw['proxyType'] is not None:
-                self.proxy_type = raw['proxyType']
+                self.proxy_type = ProxyType.load(raw['proxyType'])
             if 'ftpProxy' in raw and raw['ftpProxy'] is not None:
                 self.ftp_proxy = raw['ftpProxy']
             if 'httpProxy' in raw and raw['httpProxy'] is not None:
@@ -62,6 +76,12 @@ class Proxy(object):
                 self.sslProxy = raw['sslProxy']
             if 'autodetect' in raw and raw['autodetect'] is not None:
                 self.auto_detect = raw['autodetect']
+            if 'socksProxy' in raw and raw['socksProxy'] is not None:
+                self.socksProxy = raw['socksProxy']
+            if 'socksUsername' in raw and raw['socksUsername'] is not None:
+                self.socksUsername = raw['socksUsername']
+            if 'socksPassword' in raw and raw['socksPassword'] is not None:
+                self.socksPassword = raw['socksPassword']
 
     @property
     def proxy_type(self):
@@ -76,15 +96,15 @@ class Proxy(object):
         Sets proxy type.
 
         :Args:
-         - value: Te proxy type.
+         - value: The proxy type.
         """
-        self._verify_proxy_type_compatilibily(value)
+        self._verify_proxy_type_compatibility(value)
         self.proxyType = value
 
     @property
     def auto_detect(self):
         """
-        Returns autodect setting.
+        Returns autodetect setting.
         """
         return self.autodetect
 
@@ -98,7 +118,7 @@ class Proxy(object):
         """
         if isinstance(value, bool):
             if self.autodetect is not value:
-                self._verify_proxy_type_compatilibily(ProxyType.AUTODETECT)
+                self._verify_proxy_type_compatibility(ProxyType.AUTODETECT)
                 self.proxyType = ProxyType.AUTODETECT
                 self.autodetect = value
         else:
@@ -119,7 +139,7 @@ class Proxy(object):
         :Args:
          - value: The ftp proxy value.
         """
-        self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.ftpProxy = value
 
@@ -138,7 +158,7 @@ class Proxy(object):
         :Args:
          - value: The http proxy value.
         """
-        self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.httpProxy = value
 
@@ -157,7 +177,7 @@ class Proxy(object):
         :Args:
          - value: The noproxy value.
         """
-        self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.noProxy = value
 
@@ -176,7 +196,7 @@ class Proxy(object):
         :Args:
          - value: The proxy autoconfig url value.
         """
-        self._verify_proxy_type_compatilibily(ProxyType.PAC)
+        self._verify_proxy_type_compatibility(ProxyType.PAC)
         self.proxyType = ProxyType.PAC
         self.proxyAutoconfigUrl = value
 
@@ -195,11 +215,68 @@ class Proxy(object):
         :Args:
          - value: The https proxy value.
         """
-        self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.sslProxy = value
 
-    def _verify_proxy_type_compatilibily(self, compatibleProxy):
+    @property
+    def socks_proxy(self):
+        """
+        Returns socks proxy setting.
+        """
+        return self.socksProxy
+
+    @socks_proxy.setter
+    def socks_proxy(self, value):
+        """
+        Sets socks proxy setting.
+
+        :Args:
+         - value: The socks proxy value.
+        """
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
+        self.proxyType = ProxyType.MANUAL
+        self.socksProxy = value
+
+    @property
+    def socks_username(self):
+        """
+        Returns socks proxy username setting.
+        """
+        return self.socksUsername
+
+    @socks_username.setter
+    def socks_username(self, value):
+        """
+        Sets socks proxy username setting.
+
+        :Args:
+         - value: The socks proxy username value.
+        """
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
+        self.proxyType = ProxyType.MANUAL
+        self.socksUsername = value
+
+    @property
+    def socks_password(self):
+        """
+        Returns socks proxy password setting.
+        """
+        return self.socksPassword
+
+    @socks_password.setter
+    def socks_password(self, value):
+        """
+        Sets socks proxy password setting.
+
+        :Args:
+         - value: The socks proxy password value.
+        """
+        self._verify_proxy_type_compatibility(ProxyType.MANUAL)
+        self.proxyType = ProxyType.MANUAL
+        self.socksPassword = value
+
+    def _verify_proxy_type_compatibility(self, compatibleProxy):
         if self.proxyType != ProxyType.UNSPECIFIED and self.proxyType != compatibleProxy:
             raise Exception(" Specified proxy type (%s) not compatible with current setting (%s)" % \
                                                 (compatibleProxy, self.proxyType))
@@ -207,7 +284,7 @@ class Proxy(object):
 
     def add_to_capabilities(self, capabilities):
         """
-        Adds proxy information as capability in specified capabilties.
+        Adds proxy information as capability in specified capabilities.
 
         :Args:
          - capabilities: The capabilities to which proxy will be added.
@@ -226,4 +303,10 @@ class Proxy(object):
             proxy_caps['sslProxy'] = self.sslProxy
         if self.noProxy:
             proxy_caps['noProxy'] = self.noProxy
+        if self.socksProxy:
+            proxy_caps['socksProxy'] = self.socksProxy
+        if self.socksUsername:
+            proxy_caps['socksUsername'] = self.socksUsername
+        if self.socksPassword:
+            proxy_caps['socksPassword'] = self.socksPassword
         capabilities['proxy'] = proxy_caps
